@@ -43,7 +43,7 @@
 
 #define KGAME_LOAD_COOKIE 4210
 
-Q_LOGGING_CATEGORY(GAMES_PRIVATE_KGAME, "games.private.kgame")
+Q_LOGGING_CATEGORY(GAMES_PRIVATE_KGAME, "org.kde.games.private.kgame", QtWarningMsg)
 
 // try to place as much as possible here
 // many things are *not* possible here as KGame has to use some inline function
@@ -83,8 +83,6 @@ KGame::KGame(int cookie,QObject* parent)
     : KGameNetwork(cookie,parent),
       d( new KGamePrivate )
 {
- QLoggingCategory::setFilterRules(QStringLiteral("games.private.kgame.debug = true")); 
- 
  qCDebug(GAMES_PRIVATE_KGAME) << " - " << this << ", sizeof(KGame)=" << sizeof(KGame);
 
  d->mProperties = new KGamePropertyHandler(this);
@@ -109,7 +107,7 @@ KGame::KGame(int cookie,QObject* parent)
  setGameSequence(new KGameSequence());
 
  // BL: FIXME This signal does no longer exist. When we are merging
- // MH: super....and how do I find out about the lost conenction now?
+ // MH: super....and how do I find out about the lost connection now?
  // KGame and KGameNetwork, this could be improved!
 //  connect(this,SIGNAL(signalConnectionLost(KGameClient*)),
 //          this,SLOT(slotConnectionLost(KGameClient*)));
@@ -212,7 +210,7 @@ bool KGame::loadgame(QDataStream &stream, bool network,bool resetgame)
  // loading properties. This can cause inconsistencies
  // otherwise if a property emits and this emit accesses
  // a property not yet loaded
- // Note we habe to have this external locking to prevent the games unlocking
+ // Note we have to have this external locking to prevent the games unlocking
  // to access the players
  dataHandler()->lockDirectEmit();
 
@@ -249,7 +247,7 @@ bool KGame::loadgame(QDataStream &stream, bool network,bool resetgame)
  qint16 cookie;
  stream >> cookie;
  if (cookie==KGAME_LOAD_COOKIE) {
-   qCDebug(GAMES_PRIVATE_KGAME) << "   Game loaded propertly";
+   qCDebug(GAMES_PRIVATE_KGAME) << "   Game loaded properly";
  } else {
    qCCritical(GAMES_PRIVATE_KGAME) << "   Game loading error. probably format error";
  }
@@ -443,7 +441,7 @@ bool KGame::addPlayer(KPlayer* newplayer)
 
  QByteArray buffer;
  QDataStream stream(&buffer,QIODevice::WriteOnly);
- // We distinguis here what policy we have
+ // We distinguish here what policy we have
  if (policy()==PolicyLocal || policy()==PolicyDirty)
  {
    if ( !systemAddPlayer(newplayer) )
@@ -1092,7 +1090,7 @@ void KGame::setupGameContinue(QDataStream& stream, quint32 sender)
   qCDebug(GAMES_PRIVATE_KGAME) << "havePlayers" << cnt+playerCount()-inactivateIds.count();
   while (maxPlayers() > 0 && maxPlayers() < (int)(cnt+playerCount() - inactivateIds.count()))
   {
-    qCDebug(GAMES_PRIVATE_KGAME) << "  Still to deacticvate "
+    qCDebug(GAMES_PRIVATE_KGAME) << "  Still to deactivate "
             << (int)(cnt+playerCount()-inactivateIds.count())-(int)maxPlayers()
 ;
     KPlayer *currentPlayer=0;
@@ -1139,12 +1137,12 @@ void KGame::setupGameContinue(QDataStream& stream, quint32 sender)
     }
     else
     {
-      qCCritical(GAMES_PRIVATE_KGAME) << "Couldn't find a player to dectivate..That is not so good...";
+      qCCritical(GAMES_PRIVATE_KGAME) << "Couldn't find a player to deactivate. That is not so good...";
       break;
     }
   }
 
-  qCDebug(GAMES_PRIVATE_KGAME) << "Alltogether deactivated" << inactivateIds.count() << "players";
+  qCDebug(GAMES_PRIVATE_KGAME) << "Altogether deactivated" << inactivateIds.count() << "players";
 
   QList<int>::Iterator it;
   for ( it = inactivateIds.begin(); it != inactivateIds.end(); ++it )
